import { Engine } from 'json-rules-engine';
import { S3 } from 'aws-sdk';

function applyRules(inputData) {
  return new Promise(function (resolve, reject) {
    // Configura el cliente de S3 con las credenciales adecuadas y la región correcta
    var s3 = new S3();
    // Especifica el nombre de tu bucket y la ruta de tu archivo JSON en S3
    var bucketName = 'json-rules-engine';
    // Obtiene el archivo JSON desde S3
    s3.getObject({
      Bucket: bucketName,
      Key: inputData.nameRule
    }, function (err, s3Data) {
      if (err) {
        console.error('Error al obtener el archivo JSON desde S3:', err);
        reject(err);
        return;
      }
      if (!s3Data || !s3Data.Body) {
        console.error('El objeto s3Data o su propiedad Body es indefinido.');
        reject('El objeto s3Data o su propiedad Body es indefinido.');
        return;
      }
      var jsonRules = JSON.parse(s3Data.Body.toString()).decisions;
      console.log('Reglas JSON obtenidas desde S3:');
      console.log(jsonRules);
      var engine = new Engine();
      jsonRules.forEach(function (rule) {
        engine.addRule(rule);
      });
      engine.run(inputData.data).then(function (results) {
        return resolve([results]);
      })["catch"](function (error) {
        console.error('Error al ejecutar el motor de reglas:', error);
        reject(error);
      });
    });
  });
}

export { applyRules };
//# sourceMappingURL=engine-global-rules-lib.esm.js.map
