import { Engine, EngineResult, Rule } from 'json-rules-engine';
import * as AWS from 'aws-sdk';
import { GlobalRules } from './types/UtilTypes';

export function applyRules(inputData: GlobalRules): Promise<any[]> {
  return new Promise((resolve, reject) => {
    // Configura el cliente de S3 con las credenciales adecuadas y la región correcta
    const s3 = new AWS.S3();

    // Especifica el nombre de tu bucket y la ruta de tu archivo JSON en S3
    const bucketName = 'json-rules-engine';

    // Obtiene el archivo JSON desde S3
    s3.getObject(
      { Bucket: bucketName, Key: inputData.nameRule },
      (err, s3Data) => {
        if (err) {
          console.error('Error al obtener el archivo JSON desde S3:', err);
          reject(err);
          return;
        }

        if (!s3Data || !s3Data.Body) {
          console.error('El objeto s3Data o su propiedad Body es indefinido.');
          reject('El objeto s3Data o su propiedad Body es indefinido.');
          return;
        }

        const jsonRules: Rule[] = JSON.parse(s3Data.Body.toString()).decisions;
        console.log('Reglas JSON obtenidas desde S3:');
        console.log(jsonRules);

        const engine = new Engine();

        jsonRules.forEach(rule => {
          engine.addRule(rule);
        });

        engine
          .run(inputData.data)
          .then((results: EngineResult) => resolve([results]))
          .catch(error => {
            console.error('Error al ejecutar el motor de reglas:', error);
            reject(error);
          });
      }
    );
  });
}
